==> openturns_1.0.orig.tar.bz2: openturns-1.0/lib/test/t_RandomGenerator_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_RandomGenerator_std.cxx
 *  @brief The test file of class RandomGenerator for standard methods
 *
 *  (C) Copyright 2005-2012 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: schueller $
 *  @date:   $LastChangedDate: 2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012) $
 *  Id:      $Id: t_RandomGenerator_std.cxx 2392 2012-02-17 18:35:43Z schueller $
 */
#include <iostream>
#include <sstream>
#include <cmath>
#include "OT.hxx"
#include "OTtestcode.hxx"
#include "OStream.hxx"
#include "RandomGenerator.hxx"
#include "NumericalPoint.hxx"
#include "DistFunc.hxx"
#include "Normal.hxx"

using namespace OT;
using namespace OT::Test;


int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  try {
    // Test the initialization method
    RandomGenerator::SetSeed(0);
    // Test the state accessor for reading
    RandomGeneratorState initialState(RandomGenerator::GetState());
    fullprint << "state index=" << initialState.index_ << " state array=" << initialState.state_ << std::endl;
    // Test the generation of one realization
    NumericalScalar realization(RandomGenerator::Generate());
    fullprint << "one realization=" << realization << std::endl;
    RandomGeneratorState state(RandomGenerator::GetState());
    fullprint << "new state index=" << state.index_ << std::endl;
    // Test the generation of several realizations
    UnsignedLong size(10000);
    NumericalPoint several(RandomGenerator::Generate(size));
    fullprint << size << " realizations, first=" << several[0] << ", last=" << several[size  - 1] << std::endl;
    // Test the state accessor for writing
    RandomGenerator::SetState(initialState);
    fullprint << "restoring initial state, one realization=" << RandomGenerator::Generate() << std::endl;
    // Test the uniformity of the random generator
    size = 100000;
    NumericalPoint manyPoints(RandomGenerator::Generate(size));
    UnsignedLong slice(10);
    NumericalPoint frequencies(slice, 0.0);
    NumericalScalar mean(0.0);
    for (UnsignedLong i = 0; i < size; i++)
      {
        frequencies[(UnsignedLong)(slice * manyPoints[i])]++;
        mean += manyPoints[i];
      }
    mean /= size;
    fullprint << "mean of " << size << " realizations=" << mean << std::endl;
    for (UnsignedLong i = 0; i < slice; i++)
      {
        frequencies[i] /= size;
        fullprint << "frequency in slice [" << NumericalScalar(i) / slice << ", " << NumericalScalar(i+1) / slice << "]=" << frequencies[i] << std::endl;
      }
    fullprint << "One integer generation in [[0, " << slice-1 << "]]=" << RandomGenerator::IntegerGenerate(slice) << std::endl;
    fullprint << "Another integer generation in [[0, " << slice-1 << "]]=" << RandomGenerator::IntegerGenerate(slice) << std::endl;
    Collection<UnsignedLong> manyUnsignedLong(RandomGenerator::IntegerGenerate(size, slice));
    frequencies = NumericalPoint(slice, 0.0);
    mean = 0.0;
    for (UnsignedLong i = 0; i < size; i++)
      {
        frequencies[manyUnsignedLong[i]]++;
        mean += manyUnsignedLong[i];
      }
    mean /= size;
    fullprint << "mean of " << size << " integer realizations=" << mean << std::endl;
    for (UnsignedLong i = 0; i < slice; i++)
      {
        frequencies[i] /= size;
        fullprint << "frequency for value " << i << "=" << frequencies[i] << std::endl;
      }
  }
  catch (TestFailed & ex) {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}

==> openturns_1.2.orig.tar.bz2: openturns-1.2/lib/test/t_RandomGenerator_std.cxx <==
//                                               -*- C++ -*-
/**
 *  @file  t_RandomGenerator_std.cxx
 *  @brief The test file of class RandomGenerator for standard methods
 *
 *  Copyright (C) 2005-2013 EDF-EADS-Phimeca
 *
 *  This library is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 *  @author schueller
 *  @date   2012-02-17 19:35:43 +0100 (Fri, 17 Feb 2012)
 */
#include "OT.hxx"
#include "OTtestcode.hxx"

using namespace OT;
using namespace OT::Test;

int main(int argc, char *argv[])
{
  TESTPREAMBLE;
  OStream fullprint(std::cout);

  try
  {
    // Test the initialization method
    RandomGenerator::SetSeed(0);
    // Test the state accessor for reading
    RandomGeneratorState initialState(RandomGenerator::GetState());
    fullprint << "state index=" << initialState.index_ << " state array=" << initialState.state_ << std::endl;
    // Test the generation of one realization
    NumericalScalar realization(RandomGenerator::Generate());
    fullprint << "one realization=" << realization << std::endl;
    RandomGeneratorState state(RandomGenerator::GetState());
    fullprint << "new state index=" << state.index_ << std::endl;
    // Test the generation of several realizations
    UnsignedLong size(10000);
    NumericalPoint several(RandomGenerator::Generate(size));
    fullprint << size << " realizations, first=" << several[0] << ", last=" << several[size  - 1] << std::endl;
    // Test the state accessor for writing
    RandomGenerator::SetState(initialState);
    fullprint << "restoring initial state, one realization=" << RandomGenerator::Generate() << std::endl;
    // Test the uniformity of the random generator
    size = 100000;
    NumericalPoint manyPoints(RandomGenerator::Generate(size));
    UnsignedLong slice(10);
    NumericalPoint frequencies(slice, 0.0);
    NumericalScalar mean(0.0);
    for (UnsignedLong i = 0; i < size; i++)
    {
      frequencies[(UnsignedLong)(slice * manyPoints[i])]++;
      mean += manyPoints[i];
    }
    mean /= size;
    fullprint << "mean of " << size << " realizations=" << mean << std::endl;
    for (UnsignedLong i = 0; i < slice; i++)
    {
      frequencies[i] /= size;
      fullprint << "frequency in slice [" << NumericalScalar(i) / slice << ", " << NumericalScalar(i + 1) / slice << "]=" << frequencies[i] << std::endl;
    }
    fullprint << "One integer generation in [[0, " << slice - 1 << "]]=" << RandomGenerator::IntegerGenerate(slice) << std::endl;
    fullprint << "Another integer generation in [[0, " << slice - 1 << "]]=" << RandomGenerator::IntegerGenerate(slice) << std::endl;
    Collection<UnsignedLong> manyUnsignedLong(RandomGenerator::IntegerGenerate(size, slice));
    frequencies = NumericalPoint(slice, 0.0);
    mean = 0.0;
    for (UnsignedLong i = 0; i < size; i++)
    {
      frequencies[manyUnsignedLong[i]]++;
      mean += manyUnsignedLong[i];
    }
    mean /= size;
    fullprint << "mean of " << size << " integer realizations=" << mean << std::endl;
    for (UnsignedLong i = 0; i < slice; i++)
    {
      frequencies[i] /= size;
      fullprint << "frequency for value " << i << "=" << frequencies[i] << std::endl;
    }
  }
  catch (TestFailed & ex)
  {
    std::cerr << ex << std::endl;
    return ExitCode::Error;
  }


  return ExitCode::Success;
}
